@@ -7,6 +7,7 @@ from selenium import webdriver
 from gmapsbounds import utils
 from gmapsbounds import reader
 from gmapsbounds import constants
+from gmapsbounds import llpx
 
 class Location:
     def __init__(self, driver, name):
@@ -15,11 +16,13 @@ class Location:
         self.save_dir = tempfile.mkdtemp()
         self.center = ''
         self.zoom = ''
-        self.boundaries = []
+        self.nodes = []
 
     def download_center_map(self):
         self.load_map()
         self.center, self.zoom = utils.parse_url(self.driver.current_url)
+        center_list = [float(coord) for coord in self.center.split(', ')]
+        self.offset = llpx.lat_lng_to_pixels(center_list[0], center_list[1], self.zoom)
         if self.center in constants.ZOOM_OUT:
             self.zoom_out()
         self.take_map_screenshot('boundaries.png')
@@ -50,16 +53,18 @@ class Location:
 
     def calculate_coordinates(self):
         boundaries_filename = os.path.join(self.save_dir, 'boundaries.png')
-        rgb_im = reader.load_image(boundaries_filename)
+        rgb_im = utils.load_image(boundaries_filename)
         nodes = reader.get_nodes(rgb_im)
-        self.boundaries = reader.order_nodes(nodes, rgb_im)
-        self.boundaries = utils.prune_nodes(self.boundaries)
-        self.boundaries = utils.remove_overlapping_polygons(self.boundaries)
-        location_map = reader.Map(self.center, rgb_im.size[0], rgb_im.size[1], self.zoom)
-        location_map.attach_nodes(self.boundaries)
+        self.nodes = reader.order_nodes(nodes, rgb_im)
+        self.nodes = utils.prune_nodes(self.nodes)
+        self.nodes = utils.remove_overlapping_polygons(self.nodes)
+        self.pixcenter = [rgb_im.size[0] // 2, rgb_im.size[1] // 2]
+        for node_collection in self.nodes:
+            for node in node_collection:
+                node.location = self
         with open('cityarray.js', 'w') as f:
             f.write('var COORDINATES = [\n')
-            for node_collection in self.boundaries:
+            for node_collection in self.nodes:
                 f.write('[\n')
                 for node in node_collection:
                     lat, lng = node.get_lat_lng()
@@ -72,7 +77,7 @@ class Location:
     def as_dict(self):
         boundaries = []
         center_list = [float(coord) for coord in self.center.split(', ')]
-        for node_collection in self.boundaries:
+        for node_collection in self.nodes:
             boundaries.append([node.get_lat_lng() for node in node_collection])
         return collections.OrderedDict([
             ['name', self.name],
